<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>צילום המסך</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot to folder without gui</source>
        <translation>צילום המסך לתיקייה ללא מנשק משתמש</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>[FILE1, FILE2,...]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>תגובת שגיאה בלתי ידועה</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>תגובת שגיאה בלתי ידועה</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>תגובת שגיאה בלתי ידועה</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - מציג תמונות פשוט ומהיר

כל הזכויות שמורות (C) 2013
מיזם LXQt:‏ https://lxqt.org/‎

יוצרים:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;‎</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Open File</source>
        <translation>פתיחת קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Image files (%1)</source>
        <translation>קובצי תמונה (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Open directory</source>
        <translation>פתיחת תיקייה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>Save File</source>
        <translation>שמירת קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (בטעינה…) - מציג תמונות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (הטעינה נכשלה) - מציג תמונות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - מציג תמונות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>[*]Image Viewer</source>
        <translation>[*]מציג תמונות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="992"/>
        <source>Thumbnails</source>
        <translation>תמונות ממוזערות</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>EXIF Data</source>
        <translation>נתוני EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="45"/>
        <source>&amp;Clear</source>
        <translation>&amp;פינוי</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>התחלה</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>עצירה</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>מציג תמונות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>&amp;Recently Opened Files</source>
        <translation>קבצים שנפתחו ל&amp;אחרונה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>&amp;About</source>
        <translation>על &amp;אודות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Annotations Toolbar</source>
        <translation>סרגל כלי סימון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>&amp;Open…</source>
        <translation>&amp;פתיחה…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&amp;Reload File</source>
        <translation>&amp;רענון קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&amp;Save</source>
        <translation>&amp;שמירה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Save &amp;As</source>
        <translation>שמירה &amp;בשם</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Zoom &amp;In</source>
        <translation>הת&amp;קרבות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>Zoom &amp;Out</source>
        <translation>הת&amp;רחקות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>ה&amp;עתקה ללוח גזירים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Next File</source>
        <translation>הקובץ הבא</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="317"/>
        <source>Previous File</source>
        <translation>הקובץ הקודם</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Original Size</source>
        <translation>גודל מקורי</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Fit</source>
        <translation>הת&amp;אמה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>הטייה &amp;עם כיוון השעון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>R</source>
        <translation>ע</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>הטייה &amp;נגד כיוון השעון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>L</source>
        <translation>נ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>P&amp;references</source>
        <translation>ה&amp;עדפות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>&amp;Print</source>
        <translation>ה&amp;דפסה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>First File</source>
        <translation>קובץ ראשון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="399"/>
        <source>Last File</source>
        <translation>קובץ אחרון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>&amp;New Window</source>
        <translation>&amp;חלון חדש</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Flip &amp;Horizontally</source>
        <translation>היפוך או&amp;פקי</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>H</source>
        <translation>פ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Capture Screenshot</source>
        <translation>צילום המסך</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>F&amp;ull Screen</source>
        <translation>מ&amp;סך מלא</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Flip &amp;Vertically</source>
        <translation>היפוך א&amp;נכי</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>V</source>
        <translation>נ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>ה&amp;דבקה מלוח הגזירים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>&amp;Slide Show</source>
        <translation>מ&amp;צגת</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>&amp;Delete</source>
        <translation>מ&amp;חיקה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Show Thumbnails</source>
        <translation>הצגת תמונות ממוזערות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>T</source>
        <translation>ז</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>File Properties</source>
        <translation>מאפייני קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Open &amp;Directory</source>
        <translation>פתיחת &amp;תיקייה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Upload</source>
        <translation>העלאה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Upload the image</source>
        <translation>העלאת התמונה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Show EXIF Data</source>
        <translation>הצגת נתוני EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>No Tool</source>
        <translation>אין כלי</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Deselect all drawing tools</source>
        <translation>ביטול בחירת כל כלי הציור</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Draw Arrow</source>
        <translation>ציור חץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Draw an arrow</source>
        <translation>ציור חץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Draw Rectangle</source>
        <translation>ציור מרובע</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Draw a hollow rectangle</source>
        <translation>ציור מרובע חלול</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Draw Circle</source>
        <translation>ציור עיגול</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Draw a hollow circle</source>
        <translation>ציור עיגול חלול</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Draw Number</source>
        <translation>ציור מספר</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Draw incrementing numbers</source>
        <translation>ציור מספרים בסדר עולה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>סרגל כלי &amp;סימון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Show Outline</source>
        <translation>הצגת מתאר</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>&amp;Help</source>
        <translation>ע&amp;זרה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>Go</source>
        <translation>קדימה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>&amp;View</source>
        <translation>ת&amp;צוגה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;Edit</source>
        <translation>ע&amp;ריכה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>Toolbar</source>
        <translation>סרגל כלים</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>ערכת סמלים:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>צבע רקע כרגיל:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>צבע רקע מסך מלא:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>זמן בין החלפת תמונות (שניות):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="85"/>
        <source>Show image outline by default</source>
        <translation>הצגת המתאר של התמונה כבררת מחדל</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="92"/>
        <source>Show annotations toolbar by default</source>
        <translation>הצגת סרגל כלי הסימון כבררת מחדל</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>כללי</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>צילום המסך</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>אזור</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>המסך כולו</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>החלון הנוכחי בלבד</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>צילום אזור מסוים מהמסך</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>כולל סמן העכבר</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> שניות</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>השהיה:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>כולל הכותרת והמסגרת של החלון</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>העלאה</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>העתקה</translation>
    </message>
</context>
</TS>
